"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IDL = void 0;
exports.IDL = {
    "version": "0.1.0",
    "name": "escrow",
    "instructions": [
        {
            "name": "initializeConfig",
            "accounts": [
                {
                    "name": "config",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "funder",
                    "isMut": true,
                    "isSigner": true
                },
                {
                    "name": "systemProgram",
                    "isMut": false,
                    "isSigner": false
                }
            ],
            "args": [
                {
                    "name": "configId",
                    "type": "string"
                },
                {
                    "name": "escrowToken",
                    "type": "publicKey"
                },
                {
                    "name": "arbitratorAuthority",
                    "type": "publicKey"
                },
                {
                    "name": "bondSize",
                    "type": {
                        "vec": "u64"
                    }
                },
                {
                    "name": "arbitratorCommission",
                    "type": {
                        "vec": "u64"
                    }
                },
                {
                    "name": "paymentDuration",
                    "type": "u64"
                }
            ]
        },
        {
            "name": "makeOrder",
            "accounts": [
                {
                    "name": "escrowConfig",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "user",
                    "isMut": true,
                    "isSigner": true
                },
                {
                    "name": "tradeOrder",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "tokenMint",
                    "isMut": false,
                    "isSigner": false
                },
                {
                    "name": "userTokenAccount",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "tokenVault",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "tokenProgram",
                    "isMut": false,
                    "isSigner": false
                },
                {
                    "name": "systemProgram",
                    "isMut": false,
                    "isSigner": false
                },
                {
                    "name": "rent",
                    "isMut": false,
                    "isSigner": false
                }
            ],
            "args": [
                {
                    "name": "orderType",
                    "type": {
                        "defined": "OrderSide"
                    }
                },
                {
                    "name": "tokenAmount",
                    "type": "u64"
                },
                {
                    "name": "fiatAmount",
                    "type": "u64"
                },
                {
                    "name": "bump",
                    "type": "u8"
                }
            ]
        },
        {
            "name": "cancelOrder",
            "accounts": [
                {
                    "name": "tradeOrder",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "user",
                    "isMut": true,
                    "isSigner": true
                },
                {
                    "name": "userTokenAccount",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "tokenVault",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "tokenProgram",
                    "isMut": false,
                    "isSigner": false
                },
                {
                    "name": "rent",
                    "isMut": false,
                    "isSigner": false
                }
            ],
            "args": []
        },
        {
            "name": "joinOrder",
            "accounts": [
                {
                    "name": "tradeOrder",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "user",
                    "isMut": true,
                    "isSigner": true
                },
                {
                    "name": "userTokenAccount",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "tokenVault",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "tokenProgram",
                    "isMut": false,
                    "isSigner": false
                },
                {
                    "name": "rent",
                    "isMut": false,
                    "isSigner": false
                }
            ],
            "args": []
        },
        {
            "name": "release",
            "accounts": [
                {
                    "name": "tradeOrder",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "seller",
                    "isMut": true,
                    "isSigner": true
                },
                {
                    "name": "sellerTokenAccount",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "buyerTokenAccount",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "tokenVault",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "tokenProgram",
                    "isMut": false,
                    "isSigner": false
                },
                {
                    "name": "rent",
                    "isMut": false,
                    "isSigner": false
                }
            ],
            "args": []
        },
        {
            "name": "callArbitrator",
            "accounts": [
                {
                    "name": "escrowConfig",
                    "isMut": false,
                    "isSigner": false
                },
                {
                    "name": "tradeOrder",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "caller",
                    "isMut": true,
                    "isSigner": true
                }
            ],
            "args": []
        },
        {
            "name": "resolveDispute",
            "accounts": [
                {
                    "name": "escrowConfig",
                    "isMut": false,
                    "isSigner": false
                },
                {
                    "name": "tradeOrder",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "arbitratorAuthority",
                    "isMut": true,
                    "isSigner": true
                },
                {
                    "name": "arbitratorTokenAccount",
                    "isMut": true,
                    "isSigner": false,
                    "docs": [
                        "arbitrator_authority can specify any arbitrator_token_account"
                    ]
                },
                {
                    "name": "seller",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "sellerTokenAccount",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "buyerTokenAccount",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "tokenVault",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "tokenProgram",
                    "isMut": false,
                    "isSigner": false
                },
                {
                    "name": "rent",
                    "isMut": false,
                    "isSigner": false
                }
            ],
            "args": [
                {
                    "name": "disputeAction",
                    "type": {
                        "defined": "DisputeAction"
                    }
                },
                {
                    "name": "compensationAction",
                    "type": {
                        "defined": "CompensationAction"
                    }
                }
            ]
        }
    ],
    "accounts": [
        {
            "name": "escrowConfig",
            "type": {
                "kind": "struct",
                "fields": [
                    {
                        "name": "configId",
                        "type": "string"
                    },
                    {
                        "name": "escrowToken",
                        "type": "publicKey"
                    },
                    {
                        "name": "arbitratorAuthority",
                        "type": "publicKey"
                    },
                    {
                        "name": "currentId",
                        "type": "u64"
                    },
                    {
                        "name": "bondSize",
                        "type": {
                            "vec": "u64"
                        }
                    },
                    {
                        "name": "arbitratorCommission",
                        "type": {
                            "vec": "u64"
                        }
                    },
                    {
                        "name": "paymentDuration",
                        "type": "u64"
                    }
                ]
            }
        },
        {
            "name": "tradeOrder",
            "type": {
                "kind": "struct",
                "fields": [
                    {
                        "name": "orderId",
                        "type": "u64"
                    },
                    {
                        "name": "orderIdSeed",
                        "type": {
                            "array": [
                                "u8",
                                8
                            ]
                        }
                    },
                    {
                        "name": "side",
                        "type": {
                            "defined": "OrderSide"
                        }
                    },
                    {
                        "name": "state",
                        "type": {
                            "defined": "OrderState"
                        }
                    },
                    {
                        "name": "escrowConfig",
                        "type": "publicKey"
                    },
                    {
                        "name": "sellerAuthority",
                        "type": "publicKey"
                    },
                    {
                        "name": "sellerTokenAccount",
                        "type": "publicKey"
                    },
                    {
                        "name": "buyerAuthority",
                        "type": "publicKey"
                    },
                    {
                        "name": "buyerTokenAccount",
                        "type": "publicKey"
                    },
                    {
                        "name": "tokenMint",
                        "type": "publicKey"
                    },
                    {
                        "name": "tokenVault",
                        "type": "publicKey"
                    },
                    {
                        "name": "bondAmount",
                        "type": "u64"
                    },
                    {
                        "name": "tokenAmount",
                        "type": "u64"
                    },
                    {
                        "name": "fiatAmount",
                        "type": "u64"
                    },
                    {
                        "name": "createdAt",
                        "type": "u64"
                    },
                    {
                        "name": "joinedAt",
                        "type": "u64"
                    },
                    {
                        "name": "finishedAt",
                        "type": "u64"
                    },
                    {
                        "name": "bump",
                        "type": {
                            "array": [
                                "u8",
                                1
                            ]
                        }
                    }
                ]
            }
        }
    ],
    "types": [
        {
            "name": "ErrorCode",
            "type": {
                "kind": "enum",
                "variants": [
                    {
                        "name": "InvalidInput"
                    },
                    {
                        "name": "NumberCastError"
                    },
                    {
                        "name": "InvalidTimestampConversion"
                    },
                    {
                        "name": "InvalidTokenAccountMint"
                    },
                    {
                        "name": "InvalidState"
                    },
                    {
                        "name": "InvalidCaller"
                    },
                    {
                        "name": "StillPaymentTime"
                    },
                    {
                        "name": "UnauthorizedCanceller"
                    },
                    {
                        "name": "SelfJoin"
                    }
                ]
            }
        },
        {
            "name": "OrderState",
            "type": {
                "kind": "enum",
                "variants": [
                    {
                        "name": "Awaiting"
                    },
                    {
                        "name": "Deposited"
                    },
                    {
                        "name": "Disputed"
                    },
                    {
                        "name": "Released"
                    },
                    {
                        "name": "Canceled"
                    }
                ]
            }
        },
        {
            "name": "OrderSide",
            "type": {
                "kind": "enum",
                "variants": [
                    {
                        "name": "Buy"
                    },
                    {
                        "name": "Sell"
                    }
                ]
            }
        },
        {
            "name": "DisputeAction",
            "type": {
                "kind": "enum",
                "variants": [
                    {
                        "name": "Release"
                    },
                    {
                        "name": "Cancel"
                    }
                ]
            }
        },
        {
            "name": "CompensationAction",
            "type": {
                "kind": "enum",
                "variants": [
                    {
                        "name": "NoCompensate"
                    },
                    {
                        "name": "CompensateSeller"
                    },
                    {
                        "name": "CompensateBuyer"
                    }
                ]
            }
        }
    ]
};
