"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TradeOrderClient = void 0;
const common_sdk_1 = require("@orca-so/common-sdk");
const __1 = require("../");
const types_1 = require("../types");
class TradeOrderClient {
    constructor(ctx, publicKey, data) {
        this.ctx = ctx;
        this.data = data;
        this.publicKey = publicKey;
    }
    static getOrder(ctx, configId, orderId) {
        return __awaiter(this, void 0, void 0, function* () {
            const pda = new __1.PDA(ctx.program.programId, configId);
            const tradeOrderPublickey = pda.getTradeOrderPDA(orderId).key;
            const tradeOrderAccount = (yield ctx.program.account.tradeOrder.fetch(tradeOrderPublickey));
            if (!tradeOrderAccount) {
                throw new Error(`Trade order ${orderId} not found`);
            }
            return new TradeOrderClient(ctx, tradeOrderPublickey, tradeOrderAccount);
        });
    }
    static makeSellOrder(ctx, configId, seller, tokenMint, tokenAmount, fiatAmount) {
        return __awaiter(this, void 0, void 0, function* () {
            const pda = new __1.PDA(ctx.program.programId, configId);
            const configAddress = pda.getConfigPDA().key;
            let configAccount = (yield ctx.program.account.escrowConfig.fetch(configAddress));
            if (!configAccount) {
                throw new Error(`Escrow config ${configAddress} not found`);
            }
            const tradeOrderPDA = pda.getTradeOrderPDA(configAccount.currentId);
            const tokenVaultPDA = pda.getTokenVaultPDA(configAccount.currentId);
            const sellerTokenAccount = yield (0, common_sdk_1.deriveATA)(seller, tokenMint);
            const tx = yield (yield ctx.ixs.makeOrderIx({
                escrowConfig: configAddress,
                side: types_1.OrderSide.Sell,
                tradeOrderPDA: tradeOrderPDA,
                tokenMint: tokenMint,
                userTokenAccount: sellerTokenAccount,
                tokenVault: tokenVaultPDA,
                user: seller,
                tokenAmount: tokenAmount,
                fiatAmount: fiatAmount,
            })).toTx();
            return { tx, id: configAccount.currentId };
        });
    }
    static makeBuyOrder(ctx, configId, buyer, tokenMint, tokenAmount, fiatAmount) {
        return __awaiter(this, void 0, void 0, function* () {
            const pda = new __1.PDA(ctx.program.programId, configId);
            const configAddress = pda.getConfigPDA().key;
            let configAccount = (yield ctx.program.account.escrowConfig.fetch(configAddress));
            if (!configAccount) {
                throw new Error(`Escrow config ${configAddress} not found`);
            }
            const tradeOrderPDA = pda.getTradeOrderPDA(configAccount.currentId);
            const tokenVaultPDA = pda.getTokenVaultPDA(configAccount.currentId);
            const buyerTokenAccount = yield (0, common_sdk_1.deriveATA)(buyer, tokenMint);
            const tx = yield (yield ctx.ixs.makeOrderIx({
                escrowConfig: configAddress,
                side: types_1.OrderSide.Buy,
                tradeOrderPDA: tradeOrderPDA,
                tokenMint: tokenMint,
                userTokenAccount: buyerTokenAccount,
                tokenVault: tokenVaultPDA,
                user: buyer,
                tokenAmount: tokenAmount,
                fiatAmount: fiatAmount,
            })).toTx();
            return { tx, id: configAccount.currentId };
        });
    }
    cancelOrder(user) {
        return __awaiter(this, void 0, void 0, function* () {
            const { tokenMint, tokenVault } = this.data;
            const _a = yield (0, common_sdk_1.resolveOrCreateATA)(this.ctx.connection, user, tokenMint, () => this.ctx.fetcher.getTokenAccountRentExempt(), undefined, user), { address: userTokenAccount } = _a, instruction = __rest(_a, ["address"]);
            const tx = yield (yield this.ctx.ixs.cancelOrderIx({
                tradeOrder: this.publicKey,
                user: user,
                userTokenAccount: userTokenAccount,
                tokenVault,
            }))
                .toTx()
                .addInstruction(instruction);
            return tx;
        });
    }
    joinOrder(user) {
        return __awaiter(this, void 0, void 0, function* () {
            const { tokenMint, tokenVault } = this.data;
            const _a = yield (0, common_sdk_1.resolveOrCreateATA)(this.ctx.connection, user, tokenMint, () => this.ctx.fetcher.getTokenAccountRentExempt(), undefined, user), { address: userTokenAccount } = _a, instruction = __rest(_a, ["address"]);
            const tx = (yield this.ctx.ixs.joinSellOrderIx({
                tradeOrder: this.publicKey,
                user,
                userTokenAccount,
                tokenVault,
            }))
                .toTx()
                .addInstruction(instruction);
            return tx;
        });
    }
    release() {
        return __awaiter(this, void 0, void 0, function* () {
            const { sellerAuthority, sellerTokenAccount, buyerTokenAccount, tokenVault } = this.data;
            const tx = yield (yield this.ctx.ixs.releaseIx({
                tradeOrder: this.publicKey,
                seller: sellerAuthority,
                sellerTokenAccount,
                buyerTokenAccount,
                tokenVault,
            })).toTx();
            return tx;
        });
    }
    callArbitrator(caller) {
        return __awaiter(this, void 0, void 0, function* () {
            const tx = yield (yield this.ctx.ixs.callArbitrator({
                escrowConfig: this.data.escrowConfig,
                tradeOrder: this.publicKey,
                caller: caller,
            })).toTx();
            return tx;
        });
    }
    resolveDispute(arbitrator, disputeAction, compensationAction) {
        return __awaiter(this, void 0, void 0, function* () {
            const _a = yield (0, common_sdk_1.resolveOrCreateATA)(this.ctx.connection, arbitrator, this.data.tokenMint, () => this.ctx.fetcher.getTokenAccountRentExempt(), undefined, arbitrator), { address: arbitrator_token_account } = _a, instruction = __rest(_a, ["address"]);
            const tx = yield (yield this.ctx.ixs.resolveDispute({
                disputeAction,
                compensationAction,
                escrowConfig: this.data.escrowConfig,
                tradeOrder: this.publicKey,
                arbitratorAuthority: arbitrator,
                arbitratorTokenAccount: arbitrator_token_account,
                seller: this.data.sellerAuthority,
                sellerTokenAccount: this.data.sellerTokenAccount,
                buyerTokenAccount: this.data.buyerTokenAccount,
                tokenVault: this.data.tokenVault,
            }))
                .toTx()
                .addInstruction(instruction);
            return tx;
        });
    }
    refresh() {
        return __awaiter(this, void 0, void 0, function* () {
            const tradeOrderAccount = (yield this.ctx.program.account.tradeOrder.fetch(this.publicKey));
            this.data = tradeOrderAccount;
            return this;
        });
    }
}
exports.TradeOrderClient = TradeOrderClient;
